==> nocc-1.9.1.tbz: www/nocc/lang/fa.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: fa.php 2404 2011-03-08 22:19:54Z siebrand $
 */
/** Persian (فارسی)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Huji
 * @author Reza1615
 */

$lang_locale = 'fa.UTF-8';
$lang_dir = 'rtl';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = 'شناسه کاربر خالى است';
$err_passwd_empty = 'رمز خالى است';
$alt_delete = 'پاک کردن پيغامهاى انتخاب شده';
$alt_delete_one = 'پاک کردن پيغام';
$alt_new_msg = 'پيغامهاى جديد';
$alt_reply = 'جواب به نويسنده';
$alt_reply_all = 'جواب به همه';
$alt_forward = 'فرستادن پيغام';
$alt_next = 'بعدی';
$alt_prev = 'قبلی';
$title_next_page = 'پيغام بعدى';
$title_prev_page = 'پيغام قبلى';
$title_next_msg = 'پیام بعدی';
$title_prev_msg = 'پیام قبلی';
$html_theme_label = 'پوسته';
$html_welcome = 'خوش‌آمدید به %1$s';
$html_login = 'ورود به سامانه';
$html_user_label = 'کاربر:';
$html_passwd_label = 'کلمه عبور:';
$html_submit = 'ارسال';
$html_help = 'راهنما';
$html_server_label = 'سرور :';
$html_wrong = 'شناسه کاربر يا رمز اشتباه است';
$html_retry = 'سعى دوباره';
$html_remember = 'تنظیمات را به یاد داشته باشید';
$html_lang_label = 'زبان:';
$html_msgperpage_label = 'پيغامها به ازاء هر صفحه';
$html_preferences = 'تنظيمات';
$html_full_name_label = 'نام و نام خانوادگی :';
$html_email_address_label = 'نشانی پست الکترونیک';
$html_bccself = 'رونوشت پنهان به خود';
$html_hide_addresses = 'آدرسها به صورت پنهانى';
$html_outlook_quoting = 'نقل قول شبيه Outlook';
$html_reply_to = 'پاسخ به';
$html_use_signature = 'استفاده از امضا';
$html_signature = 'امضا';
$html_signature_label = 'امضا:';
$html_reply_leadin_label = 'نتیجه پاسخ:';
$html_prefs_updated = 'تنطيمات بروز شد';
$html_manage_folders_link = 'IMAP مدیریت پوشه های';
$html_manage_filters_link = 'مدیریت فیلترهای پست الکترونیک';
$html_use_graphical_smilies = 'استفاده از شکلک های گرافیکی';
$html_sent_folder_label = 'کپی نامه الکترونیکی به پوشه اختصاصی:';
$html_trash_folder_label = 'انتقال نامه الکترونیکی به پوشه اختصاصی:';
$html_colored_quotes = 'نقل‌قول رنگی';
$html_display_struct = 'نمایش  ساختار متن';
$html_send_html_mail = 'ارسال پست الکترونیکی در قالب متنی';
$html_folders = 'پوشه‌ها';
$html_folders_create_failed = 'شاخه نمىتواند ايجاد شود';
$html_folders_sub_failed = 'نمی‌تواند پوشه را تصدیق کند!';
$html_folders_unsub_failed = 'نمی‌تواند بدون تصدیق از پوشه!';
$html_folders_rename_failed = 'شاخه نمىتواند تغيير نام يابد';
$html_folders_updated = 'شاخه ها بروز شدند';
$html_folder_subscribe = 'اشتراک در';
$html_folder_rename = 'تغيير نام';
$html_folder_create = 'ساختن شاخه جديد صدا شد';
$html_folder_remove = 'لغو عضویت از';
$html_folder_delete = 'حذف';
$html_folder_to = 'ﺐﻫ';
$html_filter_remove = 'حذف';
$html_filter_body = 'متن پیام';
$html_filter_subject = 'موضوع پیام';
$html_filter_to = 'به زمینه';
$html_filter_cc = 'زمینه رونوشت';
$html_filter_from = 'از زمینه';
$html_filter_change_tip = ' برای تغییر یک فیلتر به سادگی آن را بازنویسی کنید';
$html_reapply_filters = 'اعمال مجدد همه فیلترها';
$html_filter_contains = 'محتویات';
$html_filter_name = 'نام فیلتر';
$html_filter_action = 'عمل فیلتر';
$html_filter_moveto = 'منتقل شد به';
$html_select_one = '-- یکی را انتخاب کنید --';
$html_and = 'و';
$html_new_msg_in = 'پيغامهاى جديد در';
$html_or = 'يا';
$html_move = 'تغيير مکان';
$html_copy = 'کپى';
$html_messages_to = 'پيغامهاى انتخاب شده به';
$html_gotopage = 'برو به صفحه';
$html_gotofolder = 'برو به شاخه';
$html_other_folders = 'ليست شاخه ها';
$html_page = 'صفحه';
$html_of = 'از';
$html_view_header = 'سرآيند را نشان بده';
$html_remove_header = 'سرآيند را پنهان کن';
$html_inbox = 'صندوق دریافتی';
$html_new_msg = 'نوشتن نامه';
$html_reply = 'پاسخ دادن';
$html_reply_short = 'پاسخ :';
$html_reply_all = 'پاسخ دادن به همه';
$html_forward = 'فرستادن';
$html_forward_short = 'باز فرست:';
$html_forward_info = ' به عنوان یک پیوست به این پیام فرستاده خواهد شد';
$html_delete = 'پاک کردن';
$html_new = 'جديد';
$html_mark = 'پاک کردن';
$html_att_label = 'پیوست :';
$html_atts_label = 'پیوست‌ها :';
$html_unknown = '[ناشناخته]';
$html_part_x = 'قسمت %s';
$html_attach = 'ضميمه کن';
$html_attach_forget = 'شما بايد فايل خود را قبل از فرستادن ضميمه کنيد';
$html_attach_delete = 'ضميمه هاى انتخاب شده را پاک کن';
$html_attach_none = 'شما باید یک فایل برای پیوست انتخاب کنید!';
$html_sort_by = 'ترتيب بندى با';
$html_sort = 'مرتب‌سازی';
$html_from = 'از';
$html_from_label = 'از:';
$html_subject = 'عنوان';
$html_subject_label = 'موضوع:';
$html_date = 'تاريخ';
$html_date_label = 'تاریخ:';
$html_sent_label = 'فرستاده شد';
$html_wrote = 'نوشت';
$html_size = 'سايز';
$html_totalsize = 'سايز کل';
$html_kb = 'کيلو بايت';
$html_mb = 'مگابایت';
$html_gb = 'گیگابایت';
$html_bytes = 'بايت';
$html_filename = 'نام فايل';
$html_to = 'به';
$html_to_label = 'به:';
$html_cc = 'کپى';
$html_cc_label = 'رونوشت:';
$html_bcc_label = 'رونوشت پنهان:';
$html_nosubject = 'بدون عنوان';
$html_send = 'بفرست';
$html_cancel = 'لغو';
$html_no_mail = 'پيغامى وجود ندارد';
$html_logout = 'خروج';
$html_msg = 'پيغام';
$html_msgs = 'پيغامها';
$html_configuration = 'اين سرور درست تنظيم نشده است';
$html_priority = 'اولویت';
$html_priority_label = 'اولویت:';
$html_lowest = 'کمترین';
$html_low = 'کم';
$html_normal = 'معمولى';
$html_high = 'زياد';
$html_highest = 'بیش‌ترین';
$html_flagged = 'پرچم گذاری شده';
$html_spam = 'هرزنامه';
$html_spam_warning = ' این پیام به عنوان هرزنامه طبقه بندی شده است.';
$html_receipt = 'درخواست رسید بازگشت';
$html_select = 'انتخاب';
$html_select_all = 'انتخاب برعکس شود';
$html_select_contacts = 'انتخاب تماس‌ها';
$html_loading_image = 'خواندن تصوير';
$html_send_confirmed = 'نامه شما براى فرستادن پذيرفته شد';
$html_no_sendaction = 'هيچ عملى انجام نشد. JavaScript را فعال نمائيد';
$html_error_occurred = 'يک خطا اتفاق افتاد';
$html_prefs_file_error = 'نمىتوانم فايل تنظيمات فردى را براى نوشتن باز کنم';
$html_wrap = 'تعداد حروف برای بسته‌بندی کردن پیام‌های خروجی';
$html_wrap_none = 'بدون لفافه';
$html_usenet_separator = 'از امضا اینترنتی ("-- \n") قبل از امضا استفاده کنید';
$html_mark_as = 'علامت‌گذاری به عنوان';
$html_read = 'خواندن';
$html_unread = 'خوانده نشده';
$html_encoding_label = 'رمزگذاری کاراکتر:';
$html_add = 'افزودن';
$html_contacts = '%1$s تماس‌ها';
$html_modify = 'تغییر';
$html_back = 'بازگشت';
$html_contact_add = 'افزودن تماس جدید';
$html_contact_mod = 'تغییر یک تماس';
$html_contact_first = 'نام:';
$html_contact_last = 'نام خانوادگی';
$html_contact_nick = 'اختصاری';
$html_contact_mail = 'پست الکترونیک';
$html_contact_list = 'فهرست تماس %1$s';
$html_contact_del = 'از لیست تماس';
$html_contact_count = '%1$d تماس‌ها';
$html_contact_err1 = 'حداکثر تعداد تماس "%1$d"';
$html_contact_err2 = 'شما نمی توانید یک تماس جدید را اضافه کنید';
$html_contact_err3 = 'شما حقوق دسترسی به لیست تماس ندارد';
$html_contact_none = 'هیچ تماسی یافت نشده است.';
$html_del_msg = 'پاک کردن پيغامهاى انتخاب شده';
$html_down_mail = 'دریافت';
$original_msg = '--پیام اصلی--';
$to_empty = 'بخش \'به\' نبایدخالی باشد!';
$html_images_warning = 'برای امنیت بیشتر خود ، ورود از راه دور نشان داده نمی شوند.';
$html_images_display = 'نمایش تصاویر';
$html_smtp_error_no_conn = 'نمىتوانم اتصال SMTP را باز کنم';
$html_smtp_error_unexpected = 'جواب غير قابل انتظار SMTP:';
$lang_could_not_connect = 'نمىتوانم به سرور متصل شوم';
$lang_invalid_msg_num = 'تعداد پیام بد';
$html_file_upload_attack = 'امکان   مشکل بارگذازی پرونده';
$html_invalid_email_address = 'نشانی پست الکترونیکی غیرمعتبر';
$html_invalid_msg_per_page = 'تعداد پبام‌های نامعتبر بع ازائ هر صفحه';
$html_invalid_wrap_msg = 'عرض بسته نامعتیر پیام';
$html_seperate_msg_win = 'پیام در پنجره جداگانه';
$html_err_file_contacts = 'نمىتوانم فايل تنظيمات فردى را براى نوشتن باز کنم';
$html_session_file_error = 'قادرنبودن به بازکردن بخش پرونده برای نوشتن';
$html_login_not_allowed = 'این ورود به سیستم برای ارتباطات اجازه ندارد';
$lang_err_send_delay = 'شما باید بین دو ایمیل صبر کنید (%1$d ثانیه)';
$html_search = 'جستجو';

==> nocc-1.9.3_1.tbz: www/nocc/lang/fa.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: fa.php 2531 2012-03-01 15:52:20Z siebrand $
 */
/** Persian (فارسی)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Ebraminio
 * @author Huji
 * @author Omnia
 * @author Reza1615
 * @author ZxxZxxZ
 */

$lang_locale = 'fa.UTF-8';
$lang_dir = 'rtl';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = 'شناسه کاربر خالى است';
$err_passwd_empty = 'رمز خالى است';
$alt_delete = 'پاک کردن پيغامهاى انتخاب شده';
$alt_delete_one = 'پاک کردن پيغام';
$alt_new_msg = 'پيغامهاى جديد';
$alt_reply = 'جواب به نويسنده';
$alt_reply_all = 'جواب به همه';
$alt_forward = 'فرستادن پيغام';
$alt_next = 'بعدی';
$alt_prev = 'قبلی';
$title_next_page = 'پيغام بعدى';
$title_prev_page = 'پيغام قبلى';
$title_next_msg = 'پیام بعدی';
$title_prev_msg = 'پیام قبلی';
$html_theme_label = 'پوسته';
$html_welcome = 'خوش‌آمدید به %1$s';
$html_login = 'ورود به سامانه';
$html_user_label = 'کاربر:';
$html_passwd_label = 'کلمه عبور:';
$html_submit = 'ارسال';
$html_help = 'راهنما';
$html_server_label = 'سرور :';
$html_wrong = 'شناسه کاربر يا رمز اشتباه است';
$html_retry = 'سعى دوباره';
$html_remember = 'تنظیمات را به یاد داشته باشید';
$html_lang_label = 'زبان:';
$html_msgperpage_label = 'پيغامها به ازاء هر صفحه';
$html_preferences = 'تنظيمات';
$html_full_name_label = 'نام و نام خانوادگی :';
$html_email_address_label = 'نشانی پست الکترونیک';
$html_bccself = 'رونوشت پنهان به خود';
$html_hide_addresses = 'آدرسها به صورت پنهانى';
$html_outlook_quoting = 'نقل قول شبيه Outlook';
$html_reply_to = 'پاسخ به';
$html_reply_to_label = 'پاسخ به :';
$html_use_signature = 'استفاده از امضا';
$html_signature = 'امضا';
$html_signature_label = 'امضا:';
$html_reply_leadin_label = 'نتیجه پاسخ:';
$html_prefs_updated = 'تنطيمات بروز شد';
$html_manage_folders_link = 'IMAP مدیریت پوشه های';
$html_manage_filters_link = 'مدیریت فیلترهای پست الکترونیک';
$html_use_graphical_smilies = 'استفاده از شکلک های گرافیکی';
$html_sent_folder_label = 'کپی نامه الکترونیکی به پوشه اختصاصی:';
$html_trash_folder_label = 'انتقال نامه الکترونیکی به پوشه اختصاصی:';
$html_colored_quotes = 'نقل‌قول رنگی';
$html_display_struct = 'نمایش  ساختار متن';
$html_send_html_mail = 'ارسال پست الکترونیکی در قالب متنی';
$html_folders = 'پوشه‌ها';
$html_folders_create_failed = 'شاخه نمىتواند ايجاد شود';
$html_folders_sub_failed = 'نمی‌تواند پوشه را تصدیق کند!';
$html_folders_unsub_failed = 'نمی‌تواند بدون تصدیق از پوشه!';
$html_folders_rename_failed = 'شاخه نمىتواند تغيير نام يابد';
$html_folders_updated = 'شاخه ها بروز شدند';
$html_folder_subscribe = 'اشتراک در';
$html_folder_rename = 'تغيير نام';
$html_folder_create = 'ساختن شاخه جديد صدا شد';
$html_folder_remove = 'لغو عضویت از';
$html_folder_delete = 'حذف';
$html_folder_to = 'ﺐﻫ';
$html_filter_remove = 'حذف';
$html_filter_body = 'متن پیام';
$html_filter_subject = 'موضوع پیام';
$html_filter_to = 'به زمینه';
$html_filter_cc = 'زمینه رونوشت';
$html_filter_from = 'از زمینه';
$html_filter_change_tip = ' برای تغییر یک فیلتر به سادگی آن را بازنویسی کنید';
$html_reapply_filters = 'اعمال مجدد همه فیلترها';
$html_filter_contains = 'محتویات';
$html_filter_name = 'نام فیلتر';
$html_filter_action = 'عمل فیلتر';
$html_filter_moveto = 'منتقل شد به';
$html_select_one = '-- یکی را انتخاب کنید --';
$html_and = 'و';
$html_new_msg_in = 'پيغامهاى جديد در';
$html_or = 'يا';
$html_move = 'تغيير مکان';
$html_copy = 'کپى';
$html_messages_to = 'پيغامهاى انتخاب شده به';
$html_gotopage = 'برو به صفحه';
$html_gotofolder = 'برو به شاخه';
$html_other_folders = 'ليست شاخه ها';
$html_page = 'صفحه';
$html_of = 'از';
$html_view_header = 'سرآيند را نشان بده';
$html_remove_header = 'سرآيند را پنهان کن';
$html_inbox = 'صندوق دریافتی';
$html_new_msg = 'نوشتن نامه';
$html_reply = 'پاسخ دادن';
$html_reply_short = 'پاسخ :';
$html_reply_all = 'پاسخ دادن به همه';
$html_forward = 'فرستادن';
$html_forward_short = 'باز فرست:';
$html_forward_info = ' به عنوان یک پیوست به این پیام فرستاده خواهد شد';
$html_delete = 'پاک کردن';
$html_new = 'جديد';
$html_mark = 'پاک کردن';
$html_att_label = 'پیوست :';
$html_atts_label = 'پیوست‌ها :';
$html_unknown = '[ناشناخته]';
$html_part_x = 'قسمت %s';
$html_attach = 'ضميمه کن';
$html_attach_forget = 'شما بايد فايل خود را قبل از فرستادن ضميمه کنيد';
$html_attach_delete = 'ضميمه هاى انتخاب شده را پاک کن';
$html_attach_none = 'شما باید یک فایل برای پیوست انتخاب کنید!';
$html_sort_by = 'مرتب‌سازی بر اساس';
$html_sort = 'مرتب‌سازی';
$html_from = 'از';
$html_from_label = 'از:';
$html_subject = 'عنوان';
$html_subject_label = 'موضوع:';
$html_date = 'تاریخ';
$html_date_label = 'تاریخ:';
$html_sent_label = 'فرستاده شد';
$html_wrote = 'نوشت';
$html_size = 'اندازه';
$html_totalsize = 'سايز کل';
$html_kb = 'کيلو بايت';
$html_mb = 'مگابایت';
$html_gb = 'گیگابایت';
$html_bytes = 'بايت';
$html_filename = 'نام فايل';
$html_to = 'به';
$html_to_label = 'به:';
$html_cc = 'کپى';
$html_cc_label = 'رونوشت:';
$html_bcc_label = 'رونوشت پنهان:';
$html_nosubject = 'بدون عنوان';
$html_send = 'بفرست';
$html_cancel = 'لغو';
$html_no_mail = 'پيغامى وجود ندارد';
$html_logout = 'خروج';
$html_msg = 'پيغام';
$html_msgs = 'پيغام‌ها';
$html_configuration = 'اين سرور درست تنظيم نشده است';
$html_priority = 'اولویت';
$html_priority_label = 'اولویت:';
$html_lowest = 'کمترین';
$html_low = 'کم';
$html_normal = 'معمولى';
$html_high = 'زياد';
$html_highest = 'بیش‌ترین';
$html_flagged = 'پرچم گذاری شده';
$html_spam = 'هرزنامه';
$html_spam_warning = ' این پیام به عنوان هرزنامه طبقه بندی شده است.';
$html_receipt = 'درخواست رسید بازگشت';
$html_select = 'انتخاب';
$html_select_all = 'انتخاب برعکس شود';
$html_select_contacts = 'انتخاب تماس‌ها';
$html_loading_image = 'خواندن تصوير';
$html_send_confirmed = 'نامه شما براى فرستادن پذيرفته شد';
$html_no_sendaction = 'هيچ عملى انجام نشد. JavaScript را فعال نمائيد';
$html_error_occurred = 'يک خطا اتفاق افتاد';
$html_prefs_file_error = 'نمىتوانم فايل تنظيمات فردى را براى نوشتن باز کنم';
$html_wrap = 'تعداد حروف برای بسته‌بندی کردن پیام‌های خروجی';
$html_wrap_none = 'بدون لفافه';
$html_usenet_separator = 'از امضا اینترنتی ("-- \n") قبل از امضا استفاده کنید';
$html_mark_as = 'علامت‌گذاری به عنوان';
$html_read = 'خواندن';
$html_unread = 'خوانده نشده';
$html_encoding_label = 'رمزگذاری کاراکتر:';
$html_add = 'افزودن';
$html_contacts = '%1$s تماس‌ها';
$html_modify = 'تغییر';
$html_back = 'بازگشت';
$html_contact_add = 'افزودن تماس جدید';
$html_contact_mod = 'تغییر یک تماس';
$html_contact_first = 'نام:';
$html_contact_last = 'نام خانوادگی';
$html_contact_nick = 'اختصاری';
$html_contact_mail = 'پست الکترونیک';
$html_contact_list = 'فهرست تماس %1$s';
$html_contact_del = 'از لیست تماس';
$html_contact_count = '%1$d تماس‌ها';
$html_contact_err1 = 'حداکثر تعداد تماس "%1$d"';
$html_contact_err2 = 'شما نمی توانید یک تماس جدید را اضافه کنید';
$html_contact_err3 = 'شما حقوق دسترسی به لیست تماس ندارد';
$html_contact_none = 'هیچ تماسی یافت نشده است.';
$html_del_msg = 'پاک کردن پيغامهاى انتخاب شده';
$html_down_mail = 'دریافت';
$original_msg = '--پیام اصلی--';
$to_empty = 'بخش \'به\' نبایدخالی باشد!';
$html_images_warning = 'برای امنیت بیشتر خود ، ورود از راه دور نشان داده نمی شوند.';
$html_images_display = 'نمایش تصاویر';
$html_smtp_error_no_conn = 'نمىتوانم اتصال SMTP را باز کنم';
$html_smtp_error_unexpected = 'جواب غير قابل انتظار SMTP:';
$lang_could_not_connect = 'نمىتوانم به سرور متصل شوم';
$lang_invalid_msg_num = 'تعداد پیام بد';
$html_file_upload_attack = 'امکان   مشکل بارگذازی پرونده';
$html_invalid_email_address = 'نشانی پست الکترونیکی غیرمعتبر';
$html_invalid_msg_per_page = 'تعداد پبام‌های نامعتبر بع ازائ هر صفحه';
$html_invalid_wrap_msg = 'عرض بسته نامعتیر پیام';
$html_seperate_msg_win = 'پیام در پنجره جداگانه';
$html_err_file_contacts = 'نمىتوانم فايل تنظيمات فردى را براى نوشتن باز کنم';
$html_session_file_error = 'قادرنبودن به بازکردن بخش پرونده برای نوشتن';
$html_login_not_allowed = 'این ورود به سیستم برای ارتباطات اجازه ندارد';
$lang_err_send_delay = 'شما باید بین دو ایمیل صبر کنید (%1$d ثانیه)';
$html_search = 'جستجو';
